"use strict";

exports.__esModule = true;
exports["default"] = plugin;
exports.shebang = void 0;

var _path = require("path");

var _package = require("@bconnorwhite/package");

var shebang = "/usr/bin/env node";
exports.shebang = shebang;

function plugin() {
  // eslint-disable-next-line no-sync
  var pkg = (0, _package.getPackageJSON)().readSync();
  var binRelatives = [];

  if (typeof (pkg == null ? void 0 : pkg.bin) === "string") {
    binRelatives.push(pkg.bin);
  } else if (typeof (pkg == null ? void 0 : pkg.bin) === "object") {
    binRelatives.push.apply(binRelatives, Object.values(pkg.bin));
  }

  var binPaths = binRelatives.map(function (relative) {
    return (0, _path.resolve)(process.cwd(), relative);
  });
  return {
    visitor: {
      Program: function Program(path, state) {
        if (state.filename && !path.hub.file.shebang && state.file.opts.sourceFileName) {
          var match = binPaths.some(function (binPath) {
            var bin = (0, _path.parse)(binPath);
            var source = (0, _path.parse)(state.filename);

            if (bin.name === source.name && (source.ext === ".ts" || source.ext === ".js")) {
              var binRelativeSource = (0, _path.resolve)(bin.dir, state.file.opts.sourceFileName);
              return binRelativeSource === state.filename;
            } else {
              return false;
            }
          });

          if (match) {
            path.hub.file.shebang = shebang;
          }
        }
      }
    }
  };
}